<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package veayo
 */
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'veayo' ); ?></a>

	<?php if ( get_header_image() ) : ?>
		<div id="site-header" class="clearfix" >
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
				<img src="<?php esc_url( header_image() ); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="">
			</a>
		</div>
	<?php endif; ?>

	<header id="masthead" class="sheader site-header clearfix">

		<nav id="primary-site-navigation" class="primary-menu main-navigation builder-box clearfix">

			<a href="#" id="pull" class="smenu-hide toggle-mobile-menu menu-toggle" aria-controls="secondary-menu" aria-expanded="false"><?php esc_html_e( 'Menu', 'veayo' ); ?></a>

			<div class="content-wrap">
			
				<?php
				wp_nav_menu( array(
					'theme_location'	=> 'menu-1',
					'menu_id'			=> 'primary-menu',
					'menu_class'		=> 'pmenu'
				) );
				?>

			</div>

		</nav><!-- #primary-site-navigation -->
		
		<div class="builder-box clearfix">
			<div class="content-wrap">

				<?php if ( has_custom_logo() ) : ?>

					<div class="site-branding branding-logo">
						<?php the_custom_logo(); ?>
					</div><!-- .site-branding -->

				<?php else : ?>

					<div class="site-branding">

						<?php if ( is_front_page() && is_home() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;

						$description = esc_html( get_bloginfo( 'description', 'display' ) );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
						<?php
						endif;
						?>

					</div><!-- .site-branding -->

				<?php
				endif;
				?>

				<?php
				if ( is_active_sidebar( 'sidebar-2' ) ) :

					dynamic_sidebar( 'sidebar-2' );

				endif;
				?>

			</div>
		</div>

		<div class="super-menu builder-box clearfix">
			<div class="super-menu-inner">

				<a href="#" id="pull" class="toggle-mobile-menu menu-toggle" aria-controls="secondary-menu" aria-expanded="false"><?php esc_html_e( 'Menu', 'veayo' ); ?></a>

			</div>
		</div>

		<?php if ( has_nav_menu( 'menu-2' ) ) : ?>

			<nav id="secondary-site-navigation" class="secondary-menu main-navigation clearfix">

				<div class="content-wrap">

					<?php
						wp_nav_menu( array(
							'theme_location'	=> 'menu-2',
							'menu_id'			=> 'secondary-menu',
							'menu_class'		=> 'smenu'
						) );
					?>

				</div>

			</nav><!-- #secondary-site-navigation -->

		<?php endif; ?>

		<div id="mobile-menu-overlay"></div>

	</header><!-- #masthead -->

	<div id="content" class="site-content clearfix">
		<div class="content-wrap">
